@@ -20,7 +20,6 @@
  * Boston, MA 02110-1301, USA.
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -49,7 +48,6 @@
 #include <libecal/e-cal-component.h>
 #include <libecal/e-cal-time-util.h>
 
-
 #include <libical/ical.h>
 #include <libsoup/soup-misc.h>
 
@@ -88,12 +86,10 @@ e_cal_backend_google_utils_populate_cache (ECalBackendGoogle *cbgo)
 	EGoItem *item;
 	ECalBackendGooglePrivate *priv;
 	icalcomponent_kind kind;
-	icaltimetype temp;
 	GSList *entries = NULL, *list = NULL;
 
 	cache = e_cal_backend_google_get_cache (cbgo);
 	kind = e_cal_backend_get_kind (E_CAL_BACKEND(cbgo));
-	temp = icaltime_current_time_with_zone (icaltimezone_get_utc_timezone ());
 
 	item = e_cal_backend_google_get_item (cbgo);
 	entries = gdata_feed_get_entries (item->feed);
@@ -117,7 +113,6 @@ e_cal_backend_google_utils_populate_cache (ECalBackendGoogle *cbgo)
 	e_cal_backend_notify_view_done (E_CAL_BACKEND(cbgo), GNOME_Evolution_Calendar_Success);
 }
 
-
 /**
  *
  * e_cal_backend_google_utils_create_cache:
@@ -160,7 +155,6 @@ e_cal_backend_google_utils_create_cache (ECalBackendGoogle *cbgo)
 	return GINT_TO_POINTER (GNOME_Evolution_Calendar_Success);
 }
 
-
 /**
  * e_cal_backend_google_utils_update:
  *
@@ -172,20 +166,18 @@ e_cal_backend_google_utils_create_cache (ECalBackendGoogle *cbgo)
 gpointer
 e_cal_backend_google_utils_update (gpointer handle)
 {
+	static gint max_results = -1;
 	ECalBackendGoogle *cbgo;
 	ECalBackendGooglePrivate *priv;
 	EGoItem *item;
-
 	ECalBackendCache *cache;
-
 	GDataGoogleService *service;
 	static GStaticMutex updating = G_STATIC_MUTEX_INIT;
 	icalcomponent_kind kind;
-
 	GSList *ids_list = NULL, *cache_keys = NULL, *entries_list = NULL;
 	GSList *uid_list = NULL, *iter_list = NULL, *remove = NULL;
 	gboolean needs_to_insert = FALSE;
-	gchar *uri;
+	gchar *uri, *full_uri;
 
 	if (!handle || !E_IS_CAL_BACKEND_GOOGLE (handle)) {
 		g_critical ("\n Invalid handle %s", G_STRLOC);
@@ -202,7 +194,20 @@ e_cal_backend_google_utils_update (gpointer handle)
 	service = e_cal_backend_google_get_service (cbgo);
 	uri = e_cal_backend_google_get_uri (cbgo);
 
-	item->feed = gdata_service_get_feed (GDATA_SERVICE(service), uri, NULL);
+	if (max_results <= 0) {
+		const gchar *env = getenv ("EVO_GOOGLE_MAX_RESULTS");
+
+		if (env)
+			max_results = atoi (env);
+
+		if (max_results <= 0)
+			max_results = 1024;
+	}
+
+	full_uri = g_strdup_printf ("%s?max-results=%d", uri, max_results);
+	item->feed = gdata_service_get_feed (GDATA_SERVICE(service), full_uri, NULL);
+	g_free (full_uri);
+
 	entries_list = gdata_feed_get_entries (item->feed);
 	cache_keys = e_cal_backend_cache_get_keys (cache);
 	kind = e_cal_backend_get_kind (E_CAL_BACKEND (cbgo));
@@ -455,8 +460,6 @@ e_go_item_to_cal_component (EGoItem *item, ECalBackendGoogle *cbgo)
 	category_ids = NULL;
 	category_ids = gdata_entry_get_categories (item->entry);
 
-	uid = gdata_entry_get_id (item->entry);
-
 	/* Classification or Visibility */
 	temp = NULL;
 	temp = gdata_entry_get_visibility (item->entry);
@@ -537,7 +540,6 @@ e_go_item_to_cal_component (EGoItem *item, ECalBackendGoogle *cbgo)
 	return comp;
 }
 
-
 /**
  *
  * e_go_item_from_cal_component:
@@ -642,7 +644,6 @@ e_go_item_get_entry (EGoItem *item)
 	return item->entry;
 }
 
-
 /**
  *
  * e_go_item_set_entry:
@@ -682,7 +683,6 @@ gdata_entry_get_entry_by_id (GSList *entries, const gchar *id)
 	return NULL;
 }
 
-
 /***************************************************************** Utility Functions *********************************************/
 
 static gint
@@ -739,7 +739,6 @@ utils_update_insertion (ECalBackendGoogle *cbgo, ECalBackendCache *cache, EGoIte
 		g_slist_free (entries_list);
 }
 
-
 static void
 utils_update_deletion (ECalBackendGoogle *cbgo, ECalBackendCache *cache, GSList *cache_keys)
 {
@@ -773,7 +772,7 @@ utils_update_deletion (ECalBackendGoogle *cbgo, ECalBackendCache *cache, GSList
  * @dt a #ECalComponentDateTime value
  **/
 /* FIXME use proper functions to manipulate the dates */
-gchar *
+static gchar *
 get_date (ECalComponentDateTime dt)
 {
 	gchar *temp;
