@@ -82,7 +82,7 @@ e_cal_backend_sync_is_read_only  (ECalBackendSync *backend, EDataCal *cal, gbool
  * Return value: Status code.
  */
 ECalBackendSyncStatus
-e_cal_backend_sync_get_cal_address  (ECalBackendSync *backend, EDataCal *cal, char **address)
+e_cal_backend_sync_get_cal_address  (ECalBackendSync *backend, EDataCal *cal, gchar **address)
 {
 	ECalBackendSyncStatus status;
 
@@ -105,7 +105,7 @@ e_cal_backend_sync_get_cal_address  (ECalBackendSync *backend, EDataCal *cal, ch
  * Return value: Status code.
  */
 ECalBackendSyncStatus
-e_cal_backend_sync_get_alarm_email_address  (ECalBackendSync *backend, EDataCal *cal, char **address)
+e_cal_backend_sync_get_alarm_email_address  (ECalBackendSync *backend, EDataCal *cal, gchar **address)
 {
 	ECalBackendSyncStatus status;
 
@@ -128,7 +128,7 @@ e_cal_backend_sync_get_alarm_email_address  (ECalBackendSync *backend, EDataCal
  * Return value: Status code.
  */
 ECalBackendSyncStatus
-e_cal_backend_sync_get_ldap_attribute  (ECalBackendSync *backend, EDataCal *cal, char **attribute)
+e_cal_backend_sync_get_ldap_attribute  (ECalBackendSync *backend, EDataCal *cal, gchar **attribute)
 {
 	ECalBackendSyncStatus status;
 
@@ -151,7 +151,7 @@ e_cal_backend_sync_get_ldap_attribute  (ECalBackendSync *backend, EDataCal *cal,
  * Return value: Status code.
  */
 ECalBackendSyncStatus
-e_cal_backend_sync_get_static_capabilities  (ECalBackendSync *backend, EDataCal *cal, char **capabilities)
+e_cal_backend_sync_get_static_capabilities  (ECalBackendSync *backend, EDataCal *cal, gchar **capabilities)
 {
 	ECalBackendSyncStatus status;
 
@@ -178,7 +178,7 @@ e_cal_backend_sync_get_static_capabilities  (ECalBackendSync *backend, EDataCal
  */
 ECalBackendSyncStatus
 e_cal_backend_sync_open  (ECalBackendSync *backend, EDataCal *cal, gboolean only_if_exists,
-			  const char *username, const char *password)
+			  const gchar *username, const gchar *password)
 {
 	ECalBackendSyncStatus status;
 
@@ -201,13 +201,13 @@ e_cal_backend_sync_open  (ECalBackendSync *backend, EDataCal *cal, gboolean only
 ECalBackendSyncStatus
 e_cal_backend_sync_remove  (ECalBackendSync *backend, EDataCal *cal)
 {
- 	ECalBackendSyncStatus status;
+	ECalBackendSyncStatus status;
 
- 	g_return_val_if_fail (backend && E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
+	g_return_val_if_fail (backend && E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
 
- 	LOCK_WRAPPER (remove_sync, (backend, cal));
+	LOCK_WRAPPER (remove_sync, (backend, cal));
 
- 	return status;
+	return status;
 }
 
 /**
@@ -222,17 +222,17 @@ e_cal_backend_sync_remove  (ECalBackendSync *backend, EDataCal *cal)
  * Return value: Status code.
  */
 ECalBackendSyncStatus
-e_cal_backend_sync_create_object (ECalBackendSync *backend, EDataCal *cal, char **calobj, char **uid)
+e_cal_backend_sync_create_object (ECalBackendSync *backend, EDataCal *cal, gchar **calobj, gchar **uid)
 {
- 	ECalBackendSyncStatus status;
+	ECalBackendSyncStatus status;
 
-  	g_return_val_if_fail (backend && E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
-  	g_return_val_if_fail (E_CAL_BACKEND_SYNC_GET_CLASS (backend)->create_object_sync != NULL,
-  			      GNOME_Evolution_Calendar_UnsupportedMethod);
+	g_return_val_if_fail (backend && E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
+	g_return_val_if_fail (E_CAL_BACKEND_SYNC_GET_CLASS (backend)->create_object_sync != NULL,
+			      GNOME_Evolution_Calendar_UnsupportedMethod);
 
- 	LOCK_WRAPPER (create_object_sync, (backend, cal, calobj, uid));
+	LOCK_WRAPPER (create_object_sync, (backend, cal, calobj, uid));
 
- 	return status;
+	return status;
 }
 
 /**
@@ -251,18 +251,18 @@ e_cal_backend_sync_create_object (ECalBackendSync *backend, EDataCal *cal, char
  * Return value: Status code.
  */
 ECalBackendSyncStatus
-e_cal_backend_sync_modify_object (ECalBackendSync *backend, EDataCal *cal, const char *calobj,
-				  CalObjModType mod, char **old_object, char **new_object)
+e_cal_backend_sync_modify_object (ECalBackendSync *backend, EDataCal *cal, const gchar *calobj,
+				  CalObjModType mod, gchar **old_object, gchar **new_object)
 {
- 	ECalBackendSyncStatus status;
+	ECalBackendSyncStatus status;
 
-  	g_return_val_if_fail (backend && E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
-  	g_return_val_if_fail (E_CAL_BACKEND_SYNC_GET_CLASS (backend)->modify_object_sync != NULL,
-  			      GNOME_Evolution_Calendar_UnsupportedMethod);
+	g_return_val_if_fail (backend && E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
+	g_return_val_if_fail (E_CAL_BACKEND_SYNC_GET_CLASS (backend)->modify_object_sync != NULL,
+			      GNOME_Evolution_Calendar_UnsupportedMethod);
 
- 	LOCK_WRAPPER (modify_object_sync, (backend, cal, calobj, mod, old_object, new_object));
+	LOCK_WRAPPER (modify_object_sync, (backend, cal, calobj, mod, old_object, new_object));
 
- 	return status;
+	return status;
 }
 
 /**
@@ -284,18 +284,18 @@ e_cal_backend_sync_modify_object (ECalBackendSync *backend, EDataCal *cal, const
  * Return value: Status code.
  */
 ECalBackendSyncStatus
-e_cal_backend_sync_remove_object (ECalBackendSync *backend, EDataCal *cal, const char *uid, const char *rid,
-				  CalObjModType mod, char **old_object, char **object)
+e_cal_backend_sync_remove_object (ECalBackendSync *backend, EDataCal *cal, const gchar *uid, const gchar *rid,
+				  CalObjModType mod, gchar **old_object, gchar **object)
 {
- 	ECalBackendSyncStatus status;
+	ECalBackendSyncStatus status;
 
-  	g_return_val_if_fail (backend && E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
-  	g_return_val_if_fail (E_CAL_BACKEND_SYNC_GET_CLASS (backend)->remove_object_sync != NULL,
-  			      GNOME_Evolution_Calendar_UnsupportedMethod);
+	g_return_val_if_fail (backend && E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
+	g_return_val_if_fail (E_CAL_BACKEND_SYNC_GET_CLASS (backend)->remove_object_sync != NULL,
+			      GNOME_Evolution_Calendar_UnsupportedMethod);
 
- 	LOCK_WRAPPER (remove_object_sync, (backend, cal, uid, rid, mod, old_object, object));
+	LOCK_WRAPPER (remove_object_sync, (backend, cal, uid, rid, mod, old_object, object));
 
- 	return status;
+	return status;
 }
 
 /**
@@ -310,17 +310,17 @@ e_cal_backend_sync_remove_object (ECalBackendSync *backend, EDataCal *cal, const
  * Return value: Status code.
  */
 ECalBackendSyncStatus
-e_cal_backend_sync_discard_alarm (ECalBackendSync *backend, EDataCal *cal, const char *uid, const char *auid)
+e_cal_backend_sync_discard_alarm (ECalBackendSync *backend, EDataCal *cal, const gchar *uid, const gchar *auid)
 {
- 	ECalBackendSyncStatus status;
+	ECalBackendSyncStatus status;
 
-  	g_return_val_if_fail (backend && E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
-  	g_return_val_if_fail (E_CAL_BACKEND_SYNC_GET_CLASS (backend)->discard_alarm_sync != NULL,
-  			      GNOME_Evolution_Calendar_UnsupportedMethod);
+	g_return_val_if_fail (backend && E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
+	g_return_val_if_fail (E_CAL_BACKEND_SYNC_GET_CLASS (backend)->discard_alarm_sync != NULL,
+			      GNOME_Evolution_Calendar_UnsupportedMethod);
 
- 	LOCK_WRAPPER (discard_alarm_sync, (backend, cal, uid, auid));
+	LOCK_WRAPPER (discard_alarm_sync, (backend, cal, uid, auid));
 
- 	return status;
+	return status;
 }
 
 /**
@@ -334,17 +334,17 @@ e_cal_backend_sync_discard_alarm (ECalBackendSync *backend, EDataCal *cal, const
  * Return value: Status code.
  */
 ECalBackendSyncStatus
-e_cal_backend_sync_receive_objects (ECalBackendSync *backend, EDataCal *cal, const char *calobj)
+e_cal_backend_sync_receive_objects (ECalBackendSync *backend, EDataCal *cal, const gchar *calobj)
 {
- 	ECalBackendSyncStatus status;
+	ECalBackendSyncStatus status;
 
-  	g_return_val_if_fail (backend && E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
-  	g_return_val_if_fail (E_CAL_BACKEND_SYNC_GET_CLASS (backend)->receive_objects_sync != NULL,
-  			      GNOME_Evolution_Calendar_UnsupportedMethod);
+	g_return_val_if_fail (backend && E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
+	g_return_val_if_fail (E_CAL_BACKEND_SYNC_GET_CLASS (backend)->receive_objects_sync != NULL,
+			      GNOME_Evolution_Calendar_UnsupportedMethod);
 
- 	LOCK_WRAPPER (receive_objects_sync, (backend, cal, calobj));
+	LOCK_WRAPPER (receive_objects_sync, (backend, cal, calobj));
 
- 	return status;
+	return status;
 }
 
 /**
@@ -360,18 +360,18 @@ e_cal_backend_sync_receive_objects (ECalBackendSync *backend, EDataCal *cal, con
  * Return value: Status code.
  */
 ECalBackendSyncStatus
-e_cal_backend_sync_send_objects (ECalBackendSync *backend, EDataCal *cal, const char *calobj, GList **users,
-				 char **modified_calobj)
+e_cal_backend_sync_send_objects (ECalBackendSync *backend, EDataCal *cal, const gchar *calobj, GList **users,
+				 gchar **modified_calobj)
 {
- 	ECalBackendSyncStatus status;
+	ECalBackendSyncStatus status;
 
-  	g_return_val_if_fail (backend && E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
-  	g_return_val_if_fail (E_CAL_BACKEND_SYNC_GET_CLASS (backend)->send_objects_sync != NULL,
-  			      GNOME_Evolution_Calendar_UnsupportedMethod);
+	g_return_val_if_fail (backend && E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
+	g_return_val_if_fail (E_CAL_BACKEND_SYNC_GET_CLASS (backend)->send_objects_sync != NULL,
+			      GNOME_Evolution_Calendar_UnsupportedMethod);
 
- 	LOCK_WRAPPER (send_objects_sync, (backend, cal, calobj, users, modified_calobj));
+	LOCK_WRAPPER (send_objects_sync, (backend, cal, calobj, users, modified_calobj));
 
- 	return status;
+	return status;
 }
 
 /**
@@ -385,16 +385,16 @@ e_cal_backend_sync_send_objects (ECalBackendSync *backend, EDataCal *cal, const
  * Return value: Status code.
  */
 ECalBackendSyncStatus
-e_cal_backend_sync_get_default_object (ECalBackendSync *backend, EDataCal *cal, char **object)
+e_cal_backend_sync_get_default_object (ECalBackendSync *backend, EDataCal *cal, gchar **object)
 {
- 	ECalBackendSyncStatus status;
+	ECalBackendSyncStatus status;
 
-  	g_return_val_if_fail (backend && E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
-  	g_return_val_if_fail (object, GNOME_Evolution_Calendar_OtherError);
+	g_return_val_if_fail (backend && E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
+	g_return_val_if_fail (object, GNOME_Evolution_Calendar_OtherError);
 
- 	LOCK_WRAPPER (get_default_object_sync, (backend, cal, object));
+	LOCK_WRAPPER (get_default_object_sync, (backend, cal, object));
 
- 	return status;
+	return status;
 }
 
 /**
@@ -411,16 +411,16 @@ e_cal_backend_sync_get_default_object (ECalBackendSync *backend, EDataCal *cal,
  * Return value: Status code.
  */
 ECalBackendSyncStatus
-e_cal_backend_sync_get_object (ECalBackendSync *backend, EDataCal *cal, const char *uid, const char *rid, char **object)
+e_cal_backend_sync_get_object (ECalBackendSync *backend, EDataCal *cal, const gchar *uid, const gchar *rid, gchar **object)
 {
- 	ECalBackendSyncStatus status;
+	ECalBackendSyncStatus status;
 
-  	g_return_val_if_fail (backend && E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
-  	g_return_val_if_fail (object, GNOME_Evolution_Calendar_OtherError);
+	g_return_val_if_fail (backend && E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
+	g_return_val_if_fail (object, GNOME_Evolution_Calendar_OtherError);
 
- 	LOCK_WRAPPER (get_object_sync, (backend, cal, uid, rid, object));
+	LOCK_WRAPPER (get_object_sync, (backend, cal, uid, rid, object));
 
- 	return status;
+	return status;
 }
 
 /**
@@ -435,16 +435,16 @@ e_cal_backend_sync_get_object (ECalBackendSync *backend, EDataCal *cal, const ch
  * Return value: Status code.
  */
 ECalBackendSyncStatus
-e_cal_backend_sync_get_object_list (ECalBackendSync *backend, EDataCal *cal, const char *sexp, GList **objects)
+e_cal_backend_sync_get_object_list (ECalBackendSync *backend, EDataCal *cal, const gchar *sexp, GList **objects)
 {
- 	ECalBackendSyncStatus status;
+	ECalBackendSyncStatus status;
 
-  	g_return_val_if_fail (backend && E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
-  	g_return_val_if_fail (objects, GNOME_Evolution_Calendar_OtherError);
+	g_return_val_if_fail (backend && E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
+	g_return_val_if_fail (objects, GNOME_Evolution_Calendar_OtherError);
 
- 	LOCK_WRAPPER (get_object_list_sync, (backend, cal, sexp, objects));
+	LOCK_WRAPPER (get_object_list_sync, (backend, cal, sexp, objects));
 
- 	return status;
+	return status;
 }
 
 /**
@@ -460,16 +460,16 @@ e_cal_backend_sync_get_object_list (ECalBackendSync *backend, EDataCal *cal, con
  * Return value: Status code.
  */
 ECalBackendSyncStatus
-e_cal_backend_sync_get_attachment_list (ECalBackendSync *backend, EDataCal *cal, const char *uid, const char *rid, GSList **attachments)
+e_cal_backend_sync_get_attachment_list (ECalBackendSync *backend, EDataCal *cal, const gchar *uid, const gchar *rid, GSList **attachments)
 {
- 	ECalBackendSyncStatus status;
+	ECalBackendSyncStatus status;
 
-  	g_return_val_if_fail (backend && E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
-  	g_return_val_if_fail (attachments, GNOME_Evolution_Calendar_OtherError);
+	g_return_val_if_fail (backend && E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
+	g_return_val_if_fail (attachments, GNOME_Evolution_Calendar_OtherError);
 
- 	LOCK_WRAPPER (get_attachment_list_sync, (backend, cal, uid, rid, attachments));
+	LOCK_WRAPPER (get_attachment_list_sync, (backend, cal, uid, rid, attachments));
 
- 	return status;
+	return status;
 }
 
 /**
@@ -484,15 +484,15 @@ e_cal_backend_sync_get_attachment_list (ECalBackendSync *backend, EDataCal *cal,
  * Return value: Status code.
  */
 ECalBackendSyncStatus
-e_cal_backend_sync_get_timezone (ECalBackendSync *backend, EDataCal *cal, const char *tzid, char **object)
+e_cal_backend_sync_get_timezone (ECalBackendSync *backend, EDataCal *cal, const gchar *tzid, gchar **object)
 {
- 	ECalBackendSyncStatus status;
+	ECalBackendSyncStatus status;
 
-  	g_return_val_if_fail (E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
+	g_return_val_if_fail (E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
 
- 	LOCK_WRAPPER (get_timezone_sync, (backend, cal, tzid, object));
+	LOCK_WRAPPER (get_timezone_sync, (backend, cal, tzid, object));
 
- 	return status;
+	return status;
 }
 
 /**
@@ -506,15 +506,15 @@ e_cal_backend_sync_get_timezone (ECalBackendSync *backend, EDataCal *cal, const
  * Return value: Status code.
  */
 ECalBackendSyncStatus
-e_cal_backend_sync_add_timezone (ECalBackendSync *backend, EDataCal *cal, const char *tzobj)
+e_cal_backend_sync_add_timezone (ECalBackendSync *backend, EDataCal *cal, const gchar *tzobj)
 {
- 	ECalBackendSyncStatus status;
+	ECalBackendSyncStatus status;
 
-  	g_return_val_if_fail (E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
+	g_return_val_if_fail (E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
 
- 	LOCK_WRAPPER (add_timezone_sync, (backend, cal, tzobj));
+	LOCK_WRAPPER (add_timezone_sync, (backend, cal, tzobj));
 
- 	return status;
+	return status;
 }
 
 /**
@@ -528,16 +528,16 @@ e_cal_backend_sync_add_timezone (ECalBackendSync *backend, EDataCal *cal, const
  * Return value: Status code.
  */
 ECalBackendSyncStatus
-e_cal_backend_sync_set_default_zone (ECalBackendSync *backend, EDataCal *cal, const char *tz)
+e_cal_backend_sync_set_default_zone (ECalBackendSync *backend, EDataCal *cal, const gchar *tz)
 {
- 	ECalBackendSyncStatus status;
+	ECalBackendSyncStatus status;
 
-  	g_return_val_if_fail (E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
+	g_return_val_if_fail (E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
 
 	/* Old backends might be using the set_default_timezone */
 	if (!E_CAL_BACKEND_SYNC_GET_CLASS (backend)->set_default_zone_sync) {
 		icalcomponent *icalcomp = icalparser_parse_string (tz);
-		const char *tzid = NULL;
+		const gchar *tzid = NULL;
 		icaltimezone *zone = icaltimezone_new ();
 
 		if (icalcomp) {
@@ -545,16 +545,16 @@ e_cal_backend_sync_set_default_zone (ECalBackendSync *backend, EDataCal *cal, co
 			tzid = icaltimezone_get_tzid (zone);
 		}
 
- 		LOCK_WRAPPER (set_default_timezone_sync, (backend, cal, tzid));
+		LOCK_WRAPPER (set_default_timezone_sync, (backend, cal, tzid));
 
 		icaltimezone_free (zone, 1);
 
 		return status;
 	}
 
- 	LOCK_WRAPPER (set_default_zone_sync, (backend, cal, tz));
+	LOCK_WRAPPER (set_default_zone_sync, (backend, cal, tz));
 
- 	return status;
+	return status;
 }
 
 /**
@@ -572,15 +572,15 @@ e_cal_backend_sync_set_default_zone (ECalBackendSync *backend, EDataCal *cal, co
  * Return value: Status code.
  */
 ECalBackendSyncStatus
-e_cal_backend_sync_set_default_timezone (ECalBackendSync *backend, EDataCal *cal, const char *tzid)
+e_cal_backend_sync_set_default_timezone (ECalBackendSync *backend, EDataCal *cal, const gchar *tzid)
 {
- 	ECalBackendSyncStatus status;
+	ECalBackendSyncStatus status;
 
-  	g_return_val_if_fail (E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
+	g_return_val_if_fail (E_IS_CAL_BACKEND_SYNC (backend), GNOME_Evolution_Calendar_OtherError);
 
- 	LOCK_WRAPPER (set_default_timezone_sync, (backend, cal, tzid));
+	LOCK_WRAPPER (set_default_timezone_sync, (backend, cal, tzid));
 
- 	return status;
+	return status;
 }
 
 /**
@@ -597,7 +597,7 @@ e_cal_backend_sync_set_default_timezone (ECalBackendSync *backend, EDataCal *cal
  * Return value: Status code.
  */
 ECalBackendSyncStatus
-e_cal_backend_sync_get_changes (ECalBackendSync *backend, EDataCal *cal, const char *change_id,
+e_cal_backend_sync_get_changes (ECalBackendSync *backend, EDataCal *cal, const gchar *change_id,
 				GList **adds, GList **modifies, GList **deletes)
 {
 	ECalBackendSyncStatus status;
@@ -647,87 +647,87 @@ _e_cal_backend_is_read_only (ECalBackend *backend, EDataCal *cal)
 }
 
 static void
-_e_cal_backend_get_cal_address (ECalBackend *backend, EDataCal *cal)
+_e_cal_backend_get_cal_address (ECalBackend *backend, EDataCal *cal, EServerMethodContext context)
 {
 	ECalBackendSyncStatus status;
-	char *address = NULL;
+	gchar *address = NULL;
 
 	status = e_cal_backend_sync_get_cal_address (E_CAL_BACKEND_SYNC (backend), cal, &address);
 
-	e_data_cal_notify_cal_address (cal, status, address);
+	e_data_cal_notify_cal_address (cal, context, status, address);
 
 	g_free (address);
 }
 
 static void
-_e_cal_backend_get_alarm_email_address (ECalBackend *backend, EDataCal *cal)
+_e_cal_backend_get_alarm_email_address (ECalBackend *backend, EDataCal *cal, EServerMethodContext context)
 {
 	ECalBackendSyncStatus status;
-	char *address = NULL;
+	gchar *address = NULL;
 
 	status = e_cal_backend_sync_get_alarm_email_address (E_CAL_BACKEND_SYNC (backend), cal, &address);
 
-	e_data_cal_notify_alarm_email_address (cal, status, address);
+	e_data_cal_notify_alarm_email_address (cal, context, status, address);
 
 	g_free (address);
 }
 
 static void
-_e_cal_backend_get_ldap_attribute (ECalBackend *backend, EDataCal *cal)
+_e_cal_backend_get_ldap_attribute (ECalBackend *backend, EDataCal *cal, EServerMethodContext context)
 {
 	ECalBackendSyncStatus status;
-	char *attribute = NULL;
+	gchar *attribute = NULL;
 
 	status = e_cal_backend_sync_get_ldap_attribute (E_CAL_BACKEND_SYNC (backend), cal, &attribute);
 
-	e_data_cal_notify_ldap_attribute (cal, status, attribute);
+	e_data_cal_notify_ldap_attribute (cal, context, status, attribute);
 
 	g_free (attribute);
 }
 
 static void
-_e_cal_backend_get_static_capabilities (ECalBackend *backend, EDataCal *cal)
+_e_cal_backend_get_static_capabilities (ECalBackend *backend, EDataCal *cal, EServerMethodContext context)
 {
 	ECalBackendSyncStatus status;
-	char *capabilities = NULL;
+	gchar *capabilities = NULL;
 
 	status = e_cal_backend_sync_get_static_capabilities (E_CAL_BACKEND_SYNC (backend), cal, &capabilities);
 
-	e_data_cal_notify_static_capabilities (cal, status, capabilities);
+	e_data_cal_notify_static_capabilities (cal, context, status, capabilities);
 
 	g_free (capabilities);
 }
 
 static void
-_e_cal_backend_open (ECalBackend *backend, EDataCal *cal, gboolean only_if_exists,
-		     const char *username, const char *password)
+_e_cal_backend_open (ECalBackend *backend, EDataCal *cal, EServerMethodContext context, gboolean only_if_exists,
+		     const gchar *username, const gchar *password)
 {
 	ECalBackendSyncStatus status;
 
 	status = e_cal_backend_sync_open (E_CAL_BACKEND_SYNC (backend), cal, only_if_exists, username, password);
 
-	e_data_cal_notify_open (cal, status);
+	e_data_cal_notify_open (cal, context, status);
 }
 
 static void
-_e_cal_backend_remove (ECalBackend *backend, EDataCal *cal)
+_e_cal_backend_remove (ECalBackend *backend, EDataCal *cal, EServerMethodContext context)
 {
 	ECalBackendSyncStatus status;
 
 	status = e_cal_backend_sync_remove (E_CAL_BACKEND_SYNC (backend), cal);
 
-	e_data_cal_notify_remove (cal, status);
+	e_data_cal_notify_remove (cal, context, status);
 }
 
 static void
-_e_cal_backend_create_object (ECalBackend *backend, EDataCal *cal, const char *calobj)
+_e_cal_backend_create_object (ECalBackend *backend, EDataCal *cal, EServerMethodContext context, const gchar *calobj)
 {
 	ECalBackendSyncStatus status;
-	char *uid = NULL, *modified_calobj = (char *) calobj;
+	gchar *uid = NULL, *modified_calobj = (gchar *) calobj;
 
 	status = e_cal_backend_sync_create_object (E_CAL_BACKEND_SYNC (backend), cal, &modified_calobj, &uid);
 
-	e_data_cal_notify_object_created (cal, status, uid, modified_calobj);
+	e_data_cal_notify_object_created (cal, context, status, uid, modified_calobj);
 
 	/* free memory */
 	if (uid)
@@ -738,29 +738,29 @@ _e_cal_backend_create_object (ECalBackend *backend, EDataCal *cal, const char *c
 }
 
 static void
-_e_cal_backend_modify_object (ECalBackend *backend, EDataCal *cal, const char *calobj, CalObjModType mod)
+_e_cal_backend_modify_object (ECalBackend *backend, EDataCal *cal, EServerMethodContext context, const gchar *calobj, CalObjModType mod)
 {
 	ECalBackendSyncStatus status;
-	char *old_object = NULL;
-	char *new_object = NULL;
+	gchar *old_object = NULL;
+	gchar *new_object = NULL;
 
 	status = e_cal_backend_sync_modify_object (E_CAL_BACKEND_SYNC (backend), cal,
 						   calobj, mod, &old_object, &new_object);
 
 	if (new_object)
-		e_data_cal_notify_object_modified (cal, status, old_object, new_object);
+		e_data_cal_notify_object_modified (cal, context, status, old_object, new_object);
 	else
-		e_data_cal_notify_object_modified (cal, status, old_object, calobj);
+		e_data_cal_notify_object_modified (cal, context, status, old_object, calobj);
 
 	g_free (old_object);
 	g_free (new_object);
 }
 
 static void
-_e_cal_backend_remove_object (ECalBackend *backend, EDataCal *cal, const char *uid, const char *rid, CalObjModType mod)
+_e_cal_backend_remove_object (ECalBackend *backend, EDataCal *cal, EServerMethodContext context, const gchar *uid, const gchar *rid, CalObjModType mod)
 {
 	ECalBackendSyncStatus status;
-	char *object = NULL, *old_object = NULL;
+	gchar *object = NULL, *old_object = NULL;
 
 	status = e_cal_backend_sync_remove_object (E_CAL_BACKEND_SYNC (backend), cal, uid, rid, mod, &old_object, &object);
 
@@ -773,47 +773,47 @@ _e_cal_backend_remove_object (ECalBackend *backend, EDataCal *cal, const char *u
 			id->rid = g_strdup (rid);
 
 		if (!object)
-			e_data_cal_notify_object_removed (cal, status, id, old_object, object);
+			e_data_cal_notify_object_removed (cal, context, status, id, old_object, object);
 		else
-			e_data_cal_notify_object_modified (cal, status, old_object, object);
+			e_data_cal_notify_object_modified (cal, context, status, old_object, object);
 
 		e_cal_component_free_id (id);
 	} else
-		e_data_cal_notify_object_removed (cal, status, NULL, old_object, object);
+		e_data_cal_notify_object_removed (cal, context, status, NULL, old_object, object);
 
 	g_free (old_object);
 	g_free (object);
 }
 
 static void
-_e_cal_backend_discard_alarm (ECalBackend *backend, EDataCal *cal, const char *uid, const char *auid)
+_e_cal_backend_discard_alarm (ECalBackend *backend, EDataCal *cal, EServerMethodContext context, const gchar *uid, const gchar *auid)
 {
 	ECalBackendSyncStatus status;
 
 	status = e_cal_backend_sync_discard_alarm (E_CAL_BACKEND_SYNC (backend), cal, uid, auid);
 
-	e_data_cal_notify_alarm_discarded (cal, status);
+	e_data_cal_notify_alarm_discarded (cal, context, status);
 }
 
 static void
-_e_cal_backend_receive_objects (ECalBackend *backend, EDataCal *cal, const char *calobj)
+_e_cal_backend_receive_objects (ECalBackend *backend, EDataCal *cal, EServerMethodContext context, const gchar *calobj)
 {
 	ECalBackendSyncStatus status;
 
 	status = e_cal_backend_sync_receive_objects (E_CAL_BACKEND_SYNC (backend), cal, calobj);
 
-	e_data_cal_notify_objects_received (cal, status);
+	e_data_cal_notify_objects_received (cal, context, status);
 }
 
 static void
-_e_cal_backend_send_objects (ECalBackend *backend, EDataCal *cal, const char *calobj)
+_e_cal_backend_send_objects (ECalBackend *backend, EDataCal *cal, EServerMethodContext context, const gchar *calobj)
 {
 	ECalBackendSyncStatus status;
 	GList *users = NULL;
-	char *modified_calobj = NULL;
+	gchar *modified_calobj = NULL;
 
 	status = e_cal_backend_sync_send_objects (E_CAL_BACKEND_SYNC (backend), cal, calobj, &users, &modified_calobj);
-	e_data_cal_notify_objects_sent (cal, status, users, modified_calobj);
+	e_data_cal_notify_objects_sent (cal, context, status, users, modified_calobj);
 
 	g_list_foreach (users, (GFunc) g_free, NULL);
 	g_list_free (users);
@@ -821,54 +821,54 @@ _e_cal_backend_send_objects (ECalBackend *backend, EDataCal *cal, const char *ca
 }
 
 static void
-_e_cal_backend_get_default_object (ECalBackend *backend, EDataCal *cal)
+_e_cal_backend_get_default_object (ECalBackend *backend, EDataCal *cal, EServerMethodContext context)
 {
 	ECalBackendSyncStatus status;
-	char *object = NULL;
+	gchar *object = NULL;
 
 	status = e_cal_backend_sync_get_default_object (E_CAL_BACKEND_SYNC (backend), cal, &object);
 
-	e_data_cal_notify_default_object (cal, status, object);
+	e_data_cal_notify_default_object (cal, context, status, object);
 
 	g_free (object);
 }
 
 static void
-_e_cal_backend_get_object (ECalBackend *backend, EDataCal *cal, const char *uid, const char *rid)
+_e_cal_backend_get_object (ECalBackend *backend, EDataCal *cal, EServerMethodContext context, const gchar *uid, const gchar *rid)
 {
 	ECalBackendSyncStatus status;
-	char *object = NULL;
+	gchar *object = NULL;
 
 	status = e_cal_backend_sync_get_object (E_CAL_BACKEND_SYNC (backend), cal, uid, rid, &object);
 
-	e_data_cal_notify_object (cal, status, object);
+	e_data_cal_notify_object (cal, context, status, object);
 
 	g_free (object);
 }
 
 static void
-_e_cal_backend_get_attachment_list (ECalBackend *backend, EDataCal *cal, const char *uid, const char *rid)
+_e_cal_backend_get_attachment_list (ECalBackend *backend, EDataCal *cal, EServerMethodContext context, const gchar *uid, const gchar *rid)
 {
 	ECalBackendSyncStatus status;
 	GSList *list = NULL;
 
 	status = e_cal_backend_sync_get_attachment_list (E_CAL_BACKEND_SYNC (backend), cal, uid, rid, &list);
 
-	e_data_cal_notify_attachment_list (cal, status, list);
+	e_data_cal_notify_attachment_list (cal, context, status, list);
 
 	g_slist_foreach (list, (GFunc) g_free, NULL);
 	g_free (list);
 }
 
 static void
-_e_cal_backend_get_object_list (ECalBackend *backend, EDataCal *cal, const char *sexp)
+_e_cal_backend_get_object_list (ECalBackend *backend, EDataCal *cal, EServerMethodContext context, const gchar *sexp)
 {
 	ECalBackendSyncStatus status;
 	GList *objects = NULL, *l;
 
 	status = e_cal_backend_sync_get_object_list (E_CAL_BACKEND_SYNC (backend), cal, sexp, &objects);
 
-	e_data_cal_notify_object_list (cal, status, objects);
+	e_data_cal_notify_object_list (cal, context, status, objects);
 
 	for (l = objects; l; l = l->next)
 		g_free (l->data);
@@ -876,16 +876,16 @@ _e_cal_backend_get_object_list (ECalBackend *backend, EDataCal *cal, const char
 }
 
 static void
-_e_cal_backend_get_timezone (ECalBackend *backend, EDataCal *cal, const char *tzid)
+_e_cal_backend_get_timezone (ECalBackend *backend, EDataCal *cal, EServerMethodContext context, const gchar *tzid)
 {
 	ECalBackendSyncStatus status;
-	char *object = NULL;
+	gchar *object = NULL;
 
 	status = e_cal_backend_sync_get_timezone (E_CAL_BACKEND_SYNC (backend), cal, tzid, &object);
 
 	if (!object && tzid) {
 		/* fallback if tzid contains only the location of timezone */
-		int i, slashes = 0;
+		gint i, slashes = 0;
 
 		for (i = 0; tzid [i]; i++) {
 			if (tzid [i] == '/')
@@ -919,8 +919,8 @@ _e_cal_backend_get_timezone (ECalBackend *backend, EDataCal *cal, const char *tz
 				}
 				icalcomponent_free (clone);
 			}
-			
-			if (free_comp)	
+
+			if (free_comp)
 				icalcomponent_free (free_comp);
 		}
 
@@ -929,25 +929,25 @@ _e_cal_backend_get_timezone (ECalBackend *backend, EDataCal *cal, const char *tz
 			e_cal_backend_sync_add_timezone (E_CAL_BACKEND_SYNC (backend), cal, object);
 	}
 
-	e_data_cal_notify_timezone_requested (cal, status, object);
+	e_data_cal_notify_timezone_requested (cal, context, status, object);
 
 	g_free (object);
 }
 
 static void
-_e_cal_backend_add_timezone (ECalBackend *backend, EDataCal *cal, const char *tzobj)
+_e_cal_backend_add_timezone (ECalBackend *backend, EDataCal *cal, EServerMethodContext context, const gchar *tzobj)
 {
 	ECalBackendSyncStatus status;
 
 	status = e_cal_backend_sync_add_timezone (E_CAL_BACKEND_SYNC (backend), cal, tzobj);
 
-	e_data_cal_notify_timezone_added (cal, status, tzobj);
+	e_data_cal_notify_timezone_added (cal, context, status, tzobj);
 }
 
 static icaltimezone *
-_e_cal_backend_internal_get_timezone (ECalBackend *backend, const char *tzid)
+_e_cal_backend_internal_get_timezone (ECalBackend *backend, const gchar *tzid)
 {
-	int i, slashes = 0;
+	gint i, slashes = 0;
 
 	if (!tzid || !*tzid)
 		return NULL;
@@ -962,27 +962,27 @@ _e_cal_backend_internal_get_timezone (ECalBackend *backend, const char *tzid)
 }
 
 static void
-_e_cal_backend_set_default_zone (ECalBackend *backend, EDataCal *cal, const char *tz)
+_e_cal_backend_set_default_zone (ECalBackend *backend, EDataCal *cal, EServerMethodContext context, const gchar *tz)
 {
 	ECalBackendSyncStatus status;
 
 	status = e_cal_backend_sync_set_default_zone (E_CAL_BACKEND_SYNC (backend), cal, tz);
 
-	e_data_cal_notify_default_timezone_set (cal, status);
+	e_data_cal_notify_default_timezone_set (cal, context, status);
 }
 
 static void
-_e_cal_backend_set_default_timezone (ECalBackend *backend, EDataCal *cal, const char *tzid)
+_e_cal_backend_set_default_timezone (ECalBackend *backend, EDataCal *cal, EServerMethodContext context, const gchar *tzid)
 {
 	ECalBackendSyncStatus status;
 
 	status = e_cal_backend_sync_set_default_timezone (E_CAL_BACKEND_SYNC (backend), cal, tzid);
 
-	e_data_cal_notify_default_timezone_set (cal, status);
+	e_data_cal_notify_default_timezone_set (cal, context, status);
 }
 
 static void
-_e_cal_backend_get_changes (ECalBackend *backend, EDataCal *cal, const char *change_id)
+_e_cal_backend_get_changes (ECalBackend *backend, EDataCal *cal, EServerMethodContext context, const gchar *change_id)
 {
 	ECalBackendSyncStatus status;
 	GList *adds = NULL, *modifies = NULL, *deletes = NULL, *l;
@@ -990,7 +990,7 @@ _e_cal_backend_get_changes (ECalBackend *backend, EDataCal *cal, const char *cha
 	status = e_cal_backend_sync_get_changes (E_CAL_BACKEND_SYNC (backend), cal, change_id,
 					       &adds, &modifies, &deletes);
 
-	e_data_cal_notify_changes (cal, status, adds, modifies, deletes);
+	e_data_cal_notify_changes (cal, context, status, adds, modifies, deletes);
 
 	for (l = adds; l; l = l->next)
 		g_free (l->data);
@@ -1006,14 +1006,14 @@ _e_cal_backend_get_changes (ECalBackend *backend, EDataCal *cal, const char *cha
 }
 
 static void
-_e_cal_backend_get_free_busy (ECalBackend *backend, EDataCal *cal, GList *users, time_t start, time_t end)
+_e_cal_backend_get_free_busy (ECalBackend *backend, EDataCal *cal, EServerMethodContext context, GList *users, time_t start, time_t end)
 {
 	ECalBackendSyncStatus status;
 	GList *freebusy = NULL, *l;
 
 	status = e_cal_backend_sync_get_free_busy (E_CAL_BACKEND_SYNC (backend), cal, users, start, end, &freebusy);
 
-	e_data_cal_notify_free_busy (cal, status, freebusy);
+	e_data_cal_notify_free_busy (cal, context, status, freebusy);
 
 	for (l = freebusy; l; l = l->next)
 		g_free (l->data);
@@ -1079,9 +1079,9 @@ e_cal_backend_sync_class_init (ECalBackendSyncClass *klass)
 	backend_class->add_timezone = _e_cal_backend_add_timezone;
 	backend_class->set_default_timezone = _e_cal_backend_set_default_timezone;
 	backend_class->set_default_zone = _e_cal_backend_set_default_zone;
- 	backend_class->get_changes = _e_cal_backend_get_changes;
- 	backend_class->get_free_busy = _e_cal_backend_get_free_busy;
- 	backend_class->internal_get_timezone = _e_cal_backend_internal_get_timezone;
+	backend_class->get_changes = _e_cal_backend_get_changes;
+	backend_class->get_free_busy = _e_cal_backend_get_free_busy;
+	backend_class->internal_get_timezone = _e_cal_backend_internal_get_timezone;
 
 	object_class->dispose = e_cal_backend_sync_dispose;
 }
