@@ -622,7 +622,7 @@ camel_read_socket (gint fd, gchar *buf, gsize n)
 			if (res == -1)
 				;
 			else if (res == 0)
-				errno = EAGAIN;
+				errno = ETIMEDOUT;
 			else if (FD_ISSET (cancel_fd, &rdset)) {
 				errno = EINTR;
 				goto failed;
@@ -697,7 +697,7 @@ camel_write_socket (gint fd, const gchar *buf, gsize n)
 			if (res == SOCKET_ERROR) {
 				/* w still being -1 will catch this */
 			} else if (res == 0)
-				errno = EAGAIN;
+				errno = ETIMEDOUT;
 			else if (FD_ISSET (cancel_fd, &rdset))
 				errno = EINTR;
 			else {
@@ -752,3 +752,38 @@ camel_file_util_savename(const gchar *filename)
 
 	return retval;
 }
+
+/**
+ * camel_mkdir:
+ * @path: directory path to create
+ * @mode: permissions
+ *
+ * Creates the directory path described in @path, creating any parent
+ * directories as necessary.
+ *
+ * Returns 0 on success or -1 on fail. In the case of failure, errno
+ * will be set appropriately.
+ **/
+gint
+camel_mkdir (const gchar *path, mode_t mode)
+{
+	gchar *copy, *p;
+
+	g_assert(path && path[0] == '/');
+
+	p = copy = g_alloca (strlen (path) + 1);
+	strcpy(copy, path);
+	do {
+		p = strchr(p + 1, '/');
+		if (p)
+			*p = '\0';
+		if (access(copy, F_OK) == -1) {
+			if (mkdir(copy, mode) == -1)
+				return -1;
+		}
+		if (p)
+			*p = '/';
+	} while (p);
+
+	return 0;
+}
