@@ -64,31 +64,31 @@ struct _CamelMsgPort {
 #endif
 };
 
-static int
-msgport_pipe (int *fds)
+static gint
+msgport_pipe (gint *fds)
 {
 #ifndef G_OS_WIN32
 	if (pipe (fds) != -1)
 		return 0;
-	
+
 	fds[0] = -1;
 	fds[1] = -1;
-	
+
 	return -1;
 #else
 	SOCKET temp, socket1 = -1, socket2 = -1;
 	struct sockaddr_in saddr;
-	int len;
+	gint len;
 	u_long arg;
 	fd_set read_set, write_set;
 	struct timeval tv;
 
 	temp = socket (AF_INET, SOCK_STREAM, 0);
-	
+
 	if (temp == INVALID_SOCKET) {
 		goto out0;
 	}
-  	
+
 	arg = 1;
 	if (ioctlsocket (temp, FIONBIO, &arg) == SOCKET_ERROR) {
 		goto out0;
@@ -113,13 +113,13 @@ msgport_pipe (int *fds)
 	}
 
 	socket1 = socket (AF_INET, SOCK_STREAM, 0);
-	
+
 	if (socket1 == INVALID_SOCKET) {
 		goto out0;
 	}
 
 	arg = 1;
-	if (ioctlsocket (socket1, FIONBIO, &arg) == SOCKET_ERROR) { 
+	if (ioctlsocket (socket1, FIONBIO, &arg) == SOCKET_ERROR) {
 		goto out1;
 	}
 
@@ -185,17 +185,17 @@ out1:
 out0:
 	closesocket (temp);
 	errno = EMFILE;		/* FIXME: use the real syscall errno? */
-	
+
 	fds[0] = -1;
 	fds[1] = -1;
-	
+
 	return -1;
 
 #endif
 }
 
 #ifdef HAVE_NSS
-static int
+static gint
 msgport_prpipe (PRFileDesc **fds)
 {
 #ifdef G_OS_WIN32
@@ -205,10 +205,10 @@ msgport_prpipe (PRFileDesc **fds)
 	if (PR_CreatePipe (&fds[0], &fds[1]) != PR_FAILURE)
 		return 0;
 #endif
-	
+
 	fds[0] = NULL;
 	fds[1] = NULL;
-	
+
 	return -1;
 }
 #endif
