@@ -20,7 +20,6 @@
  *
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -35,9 +34,9 @@
 
 CamelServiceAuthType camel_sasl_anonymous_authtype = {
 	N_("Anonymous"),
-	
+
 	N_("This option will connect to the server using an anonymous login."),
-	
+
 	"ANONYMOUS",
 	FALSE
 };
@@ -53,9 +52,9 @@ static void
 camel_sasl_anonymous_class_init (CamelSaslAnonymousClass *camel_sasl_anonymous_class)
 {
 	CamelSaslClass *camel_sasl_class = CAMEL_SASL_CLASS (camel_sasl_anonymous_class);
-	
+
 	parent_class = CAMEL_SASL_CLASS (camel_type_get_global_classfuncs (camel_sasl_get_type ()));
-	
+
 	/* virtual method overload */
 	camel_sasl_class->challenge = anon_challenge;
 }
@@ -64,16 +63,15 @@ static void
 camel_sasl_anonymous_finalize (CamelObject *object)
 {
 	CamelSaslAnonymous *sasl = CAMEL_SASL_ANONYMOUS (object);
-	
+
 	g_free (sasl->trace_info);
 }
 
-
 CamelType
 camel_sasl_anonymous_get_type (void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register (camel_sasl_get_type (),
 					    "CamelSaslAnonymous",
@@ -84,11 +82,10 @@ camel_sasl_anonymous_get_type (void)
 					    NULL,
 					    (CamelObjectFinalizeFunc) camel_sasl_anonymous_finalize);
 	}
-	
+
 	return type;
 }
 
-
 /**
  * camel_sasl_anonymous_new:
  * @type: trace type
@@ -99,16 +96,16 @@ camel_sasl_anonymous_get_type (void)
  * Returns: a new #CamelSasl object
  **/
 CamelSasl *
-camel_sasl_anonymous_new (CamelSaslAnonTraceType type, const char *trace_info)
+camel_sasl_anonymous_new (CamelSaslAnonTraceType type, const gchar *trace_info)
 {
 	CamelSaslAnonymous *sasl_anon;
-	
+
 	if (!trace_info && type != CAMEL_SASL_ANON_TRACE_EMPTY) return NULL;
-	
+
 	sasl_anon = CAMEL_SASL_ANONYMOUS (camel_object_new (camel_sasl_anonymous_get_type ()));
 	sasl_anon->trace_info = g_strdup (trace_info);
 	sasl_anon->type = type;
-	
+
 	return CAMEL_SASL (sasl_anon);
 }
 
