@@ -5,7 +5,7 @@
  * Author:
  *  Bertrand Guiheneuf <bertrand@helixcode.com>
  *
- * Copyright 1999, 2000 Ximian, Inc. (www.ximian.com)
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -18,11 +18,10 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
-
 #ifndef CAMEL_SEEKABLE_STREAM_H
 #define CAMEL_SEEKABLE_STREAM_H 1
 
@@ -60,7 +59,7 @@ typedef struct {
 	off_t (*seek)       (CamelSeekableStream *stream, off_t offset,
 			     CamelStreamSeekPolicy policy);
 	off_t (*tell)	    (CamelSeekableStream *stream);
-	int  (*set_bounds)  (CamelSeekableStream *stream,
+	gint  (*set_bounds)  (CamelSeekableStream *stream,
 			     off_t start, off_t end);
 } CamelSeekableStreamClass;
 
@@ -70,8 +69,8 @@ CamelType camel_seekable_stream_get_type (void);
 /* public methods */
 off_t    camel_seekable_stream_seek            (CamelSeekableStream *stream, off_t offset,
 						CamelStreamSeekPolicy policy);
-off_t	 camel_seekable_stream_tell    	       (CamelSeekableStream *stream);
-int	 camel_seekable_stream_set_bounds      (CamelSeekableStream *stream, off_t start, off_t end);
+off_t	 camel_seekable_stream_tell	       (CamelSeekableStream *stream);
+gint	 camel_seekable_stream_set_bounds      (CamelSeekableStream *stream, off_t start, off_t end);
 
 G_END_DECLS
 
